@@ -1,20 +1,15 @@
 package Solaris::SMF;
 
-BEGIN {
-    eval {
-        require Data::Dumper;
-    }
-};
 use warnings;
 use strict;
 require Exporter;
 our @ISA    = qw(Exporter);
 our @EXPORT = qw( get_services );
+use Readonly;
 use Params::Validate qw ( validate :types );
 use Solaris::SMF::Service;
-use Carp;
 
-my $debug = $ENV{RELEASE_TESTING} ? $ENV{RELEASE_TESTING} : 0;
+my $debug = $ENV{RELEASE_TESTING}?$ENV{RELEASE_TESTING}:0;
 
 =head1 NAME
 
@@ -22,11 +17,11 @@ Solaris::SMF - Manipulate Solaris 10 services from Perl
 
 =head1 VERSION
 
-Version 0.03_01
+Version 0.01
 
 =cut
 
-our $VERSION = '0.03_01';
+our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
@@ -57,16 +52,18 @@ Returns a list of Solaris::SMF::Service objects.
 
 =cut
 
+
 sub get_services {
-    $debug && warn( 'get_services ' . join( ',', @_ ) );
-    my %p = validate( @_, { wildcard => { type => SCALAR, default => '*' } } );
+    $debug && carp('get_services ' . join(',', @_));
+    my %p
+        = validate( @_, { wildcard => { type => SCALAR, default => '*' } } );
     local $ENV{PATH} = '/bin:/usr/bin:/sbin:/usr/sbin';
+    Readonly my $svcs => '/usr/bin/svcs';
     my @service_list;
-    open my $svc_list, '-|', " svcs -aH '$p{wildcard}' 2>/dev/null"
-      or die 'Unable to query SMF services';
+    open my $svc_list, '-|', " $svcs -aH '$p{wildcard}' 2>/dev/null"
+        or die 'Unable to query SMF services';
     while ( my $svc_line = <$svc_list> ) {
-        $debug
-          && warn($svc_line);
+        $debug && carp(Data::Dumper->Dump([$svc_line], [qw($svc_line)]));
         my ( $state, $date, $FMRI ) = (
             $svc_line =~ m/ 
 		^ 
@@ -79,13 +76,7 @@ sub get_services {
 		$ 
 	/xms
         );
-        $debug && 
-            warn(
-                Data::Dumper->Dump(
-                    [ $state, $date, $FMRI ],
-                    [qw($state $date $FMRI)]
-                )
-            );
+        $debug && carp(Data::Dumper->Dump([$state, $date, $FMRI], [qw($state $date $FMRI)]));
         if ($FMRI) {
             push( @service_list, Solaris::SMF::Service->new($FMRI) );
         }
